%global upstream_name multipath-tools

Summary:        Tools to manage multipath devices using device-mapper
Name:            device-mapper-multipath
Version:        0.9.5
Release:        3%{?dist}
License:        GPLv2
URL:            http://christophe.varoqui.free.fr/
Source0:        https://github.com/opensvc/%{upstream_name}/archive/%{version}.tar.gz #/%{upstream_name}-%{version}.tar.gz
Source1:        multipath.conf

Patch3000:      0001-RH-fixup-udev-rules-for-redhat.patch
Patch3001:      0002-RH-Remove-the-property-blacklist-exception-builtin.patch
Patch3002:      0006-RH-add-mpathconf.patch
Patch3003:      0007-RH-add-wwids-from-kernel-cmdline-mpath.wwids-with-A.patch
Patch3004:      0009-RH-attempt-to-get-ANA-info-via-sysfs-first.patch
Patch3005:      0010-RH-make-parse_vpd_pg83-match-scsi_id-output.patch
Patch3006:      0011-RH-add-scsi-device-handlers-to-modules-load.d.patch
Patch3007:      0012-RH-compile-with-libreadline-support.patch
# If multipathd starts without config, cgroup will fail because RR process will be
# created which is forked from multipath.service.
Patch3008:      don-t-start-without-a-config-file.patch

BuildRequires:    libaio-devel device-mapper-devel libselinux-devel libsepol-devel
BuildRequires:    readline-devel ncurses-devel systemd-units systemd-devel
BuildRequires:    json-c-devel perl-interpreter userspace-rcu-devel libmount-devel
BuildRequires:    make pkgconfig gcc
Requires:        %{name}-libs = %{version}-%{release}
Requires:        kpartx = %{version}-%{release}
Requires:        device-mapper >= 1.02.96
Requires:        userspace-rcu
Requires(post):        systemd-units
Requires(preun):    systemd-units
Requires(postun):    systemd-units

%description
This package provides the following binaries to drive the Device Mapper 
multipathing driver:
* multipath - Device mapper target autoconfig.
* multipathd - Multipath daemon.

%package libs
Summary:    The %{name} modules and shared libraries
License:    GPLv2 and LGPLv2+

%description libs
This package provides the %{name} modules and shared libraries.

%package devel
Summary:    Header files and libraries for %{name} development
Requires:    %{name} = %{version}-%{release}
Requires:    %{name}-libs = %{version}-%{release}

%description devel
This package provides header files and libraries for %{name} 
development.

%package -n kpartx
Summary:    Partition device manager for device-mapper devices

%description -n kpartx
kpartx manages partition creation and removal for device-mapper devices.

%package -n libdmmp
Summary:    device-mapper-multipath C API library
License:    GPLv3+
Requires:    %{name} = %{version}-%{release}
Requires:    %{name}-libs = %{version}-%{release}
Requires:    json-c

%description -n libdmmp
This package provides the shared library for the device-mapper-multipath
C API library.

%package -n libdmmp-devel
Summary:    Header files and libraries for libdmmp development
Requires:    libdmmp = %{version}-%{release}
Requires:    pkgconfig

%description -n libdmmp-devel
This package provides header files and libraries for libdmmp development.

%prep
%autosetup -n %{upstream_name}-%{version} -p1
cp %{SOURCE1} .

%build
export CFLAGS=$(echo %optflags | sed 's/-Wp,-D_FORTIFY_SOURCE=2//')
%make_build LIB=%{_lib}

%install
%make_install \
    bindir=%{_sbindir} \
    syslibdir=%{_libdir} \
    usrlibdir=%{_libdir} \
    plugindir=%{_libdir}/multipath \
    unitdir=%{_unitdir} \
    includedir=%{_includedir} \
    pkgconfdir=%{_libdir}/pkgconfig

install -d %{buildroot}%{_sysconfdir}/multipath

%post
%systemd_post multipathd.service

%preun
%systemd_preun multipathd.service

%postun
if [ $1 -ge 1 ] ; then
    /sbin/multipathd forcequeueing daemon > /dev/null 2>&1 || :
fi
%systemd_postun_with_restart multipathd.service

%files
%license LICENSES/GPL-2.0 LICENSES/LGPL-2.0 LICENSES/GPL-3.0
%doc README.md multipath.conf
%{_unitdir}/multipathd.service
%{_unitdir}/multipathd.socket
%config %{_udevrulesdir}/62-multipath.rules
%config %{_udevrulesdir}/11-dm-mpath.rules
%{_tmpfilesdir}/multipath.conf
%dir %{_modulesloaddir}
%{_modulesloaddir}/multipath.conf
%{_modulesloaddir}/scsi_dh.conf
%dir %{_sysconfdir}/multipath
%{_sbindir}/multipath
%{_sbindir}/multipathd
%{_sbindir}/multipathc
%{_sbindir}/mpathconf
%{_sbindir}/mpathpersist
%{_mandir}/man5/multipath.conf.5.gz
%{_mandir}/man8/multipath.8.gz
%{_mandir}/man8/multipathd.8.gz
%{_mandir}/man8/multipathc.8.gz
%{_mandir}/man8/mpathconf.8.gz
%{_mandir}/man8/mpathpersist.8.gz

%files libs
%license LICENSES/GPL-2.0 LICENSES/LGPL-2.0 LICENSES/LGPL-2.1
%doc README.md
%{_libdir}/libmultipath.so
%{_libdir}/libmultipath.so.*
%{_libdir}/libmpathutil.so
%{_libdir}/libmpathutil.so.*
%{_libdir}/libmpathpersist.so.*
%{_libdir}/libmpathcmd.so.*
%{_libdir}/libmpathvalid.so.*
%dir %{_libdir}/multipath
%{_libdir}/multipath/*

%files devel
%doc README.md
%{_includedir}/mpath_cmd.h
%{_includedir}/mpath_persist.h
%{_includedir}/mpath_valid.h
%{_libdir}/libmpathpersist.so
%{_libdir}/libmpathcmd.so
%{_libdir}/libmpathvalid.so
%{_mandir}/man3/mpath_persistent_reserve_in.3.gz
%{_mandir}/man3/mpath_persistent_reserve_out.3.gz

%files -n kpartx
%license LICENSES/GPL-2.0
%doc README.md
/usr/lib/udev/kpartx_id
%config %{_udevrulesdir}/11-dm-parts.rules
%config %{_udevrulesdir}/66-kpartx.rules
%config %{_udevrulesdir}/68-del-part-nodes.rules
%{_sbindir}/kpartx
%{_mandir}/man8/kpartx.8.gz

%files -n libdmmp
%license LICENSES/GPL-3.0
%doc README.md
%{_libdir}/libdmmp.so.*

%files -n libdmmp-devel
%doc README.md
%dir %{_includedir}/libdmmp
%{_includedir}/libdmmp/*
%{_libdir}/pkgconfig/libdmmp.pc
%{_libdir}/libdmmp.so
%{_mandir}/man3/dmmp_*
%{_mandir}/man3/libdmmp.h.3.gz

%changelog
* Thu Nov 02 2023 cunshunxia <cunshunxia@tencent.com> - 0.9.5-3
- add ConditionPathExists= for multipathd.service.

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.9.5-2
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 23 2023 kianli <kianli@tencent.com> - 0.9.5-1
- Upgrade to 0.9.5

* Wed Aug 23 2023 Shuo Wang <abushwang@tencent.com> - 0.9.0-4
- Rebuilt for userspace-rcu 0.14.0

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.9.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.9.0-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Jul 13 2022 Xiaojie Chen <jackxjchen@tencent.com> - 0.9.0-1
- Initial build
